HeaderEntry

Struct HeaderEntry 

pub struct HeaderEntry {
    pub hash: Hash,
    /* private fields */
}
Header entry for storing in the header MMR. Note: we hash the block header itself and maintain the hash in the entry. This allows us to lookup the original header from the db as necessary.

Fields

hash: Hash

Hash for the BlockHeader